@@ -2,4 +2,4 @@ from .callbacks import *
 from .data import *
 from .engine import *
 from .modules import *
-from .utils import *
+from .utils import Estimator
