@@ -1,4 +1,4 @@
-from .densities import log_prob_standard_normal, log_prob_standard_gmm, generate_random_gmm
+from .densities import log_prob_standard_normal, log_prob_standard_gmm
 from .softgrad import gumbel_softmax, softround
 from .metrics import accuracy, precision, average_precision, recall, roc_auc_score, pr_auc_score, \
     f1_score
