@@ -1,11 +1,12 @@
-from .distribution import TransformedNormalLoss
+from .distribution import TransformedNormalLoss, TransformedGmmLoss
 from .gp import GradientPenalty
 from .lstm import StackedLSTM, StackedLSTMCell
 from .made import MADE
 from .normalizing import NormalizingFlow
 from .residual import LinearResidual
 from .transforms import AffineTransform, PlanarTransform, RadialTransform, \
-    AffineCouplingTransform1d, MaskedAutoregressiveTransform1d, BatchNormTransform1d
+    AffineCouplingTransform1d, MaskedAutoregressiveTransform1d, BatchNormTransform1d, \
+    LeakyReLUTransform, PReLUTransform
 from .vae import VAELoss
 from .view import View
 from .wasserstein import WassersteinLossGenerator, WassersteinLossCritic
